Documentation
¶
Index ¶
- Variables
- func NewMissingPrimaryKeyError(table string) error
- func NewReplicaIdentityIndexError(table string) error
- func NewReplicaIdentityNothingError(table string, cause error) error
- type ApplicationErrorType
- type AuthError
- type BigQueryError
- type CatalogError
- type ClickHouseQRepSyncError
- type DropFlowError
- type MissingPrimaryKeyError
- type MongoInvalidIdValueError
- type MySQLGeometryParseError
- type MySQLIncompatibleColumnTypeError
- type MySQLStreamingError
- type MySQLUnsupportedBinlogRowMetadataError
- type MySQLUnsupportedDDLError
- type NormalizationError
- type NotFoundError
- type NumericOutOfRangeError
- type NumericTruncatedError
- type PeerCreateError
- type PostgresLogicalMessageProcessingError
- type PostgresSetupError
- type PostgresWalError
- type PrimaryKeyModifiedError
- type PublicationMissingError
- type RDSIAMAuthError
- type RecordMetricsError
- type ReplStateDesyncError
- type ReplicaIdentityIndexError
- type ReplicaIdentityNothingError
- type SSHTunnelSetupError
- type SlotMissingError
- type TableRemovalInCancellationError
- type TablesNotInPublicationError
Constants ¶
This section is empty.
Variables ¶
var ( ApplicationErrorTypeIrrecoverableInvalidSnapshot = NewIrrecoverableApplicationErrorType("irrecoverable_invalid_snapshot") ApplicationErrorTypeIrrecoverableCouldNotImportSnapshot = NewIrrecoverableApplicationErrorType("irrecoverable_could_not_import_snapshot") ApplicationErrorTypeIrrecoverableExistingSlot = NewIrrecoverableApplicationErrorType("irrecoverable_existing_slot") ApplicationErrorTypeIrrecoverableMissingTables = NewIrrecoverableApplicationErrorType("irrecoverable_missing_tables") )
var InvalidSequenceRe = regexp.MustCompile(`invalid sequence \d+ != \d+`)
InvalidSequenceRe go-mysql-org returns "invalid sequence X != Y" when the TCP packet sequence is out of sync — always transient, safe to retry.
var IrrecoverableApplicationErrorTypesList = make([]string, 0)
var IrrecoverableApplicationErrorTypesMap = make(map[string]struct{})
Functions ¶
Types ¶
type ApplicationErrorType ¶
type ApplicationErrorType string
func NewIrrecoverableApplicationErrorType ¶
func NewIrrecoverableApplicationErrorType(errorType string) ApplicationErrorType
func (ApplicationErrorType) String ¶
func (a ApplicationErrorType) String() string
type AuthError ¶
type AuthError struct {
// contains filtered or unexported fields
}
func NewAuthError ¶
type BigQueryError ¶
type BigQueryError struct {
// contains filtered or unexported fields
}
func NewBigQueryError ¶
func NewBigQueryError(err error) *BigQueryError
func (*BigQueryError) Error ¶
func (e *BigQueryError) Error() string
func (*BigQueryError) Unwrap ¶
func (e *BigQueryError) Unwrap() error
type CatalogError ¶
type CatalogError struct {
// contains filtered or unexported fields
}
func NewCatalogError ¶
func NewCatalogError(err error) *CatalogError
func (*CatalogError) Unwrap ¶
func (e *CatalogError) Unwrap() error
type ClickHouseQRepSyncError ¶
type ClickHouseQRepSyncError struct {
DestinationTable string
DestinationDatabase string
// contains filtered or unexported fields
}
func NewClickHouseQRepSyncError ¶
func NewClickHouseQRepSyncError(err error, destinationTable string, destinationDatabase string) *ClickHouseQRepSyncError
func (*ClickHouseQRepSyncError) Error ¶
func (e *ClickHouseQRepSyncError) Error() string
func (*ClickHouseQRepSyncError) Unwrap ¶
func (e *ClickHouseQRepSyncError) Unwrap() error
type DropFlowError ¶
type DropFlowError struct {
// contains filtered or unexported fields
}
func NewDropFlowError ¶
func NewDropFlowError(err error) *DropFlowError
func (*DropFlowError) Error ¶
func (e *DropFlowError) Error() string
func (*DropFlowError) Unwrap ¶
func (e *DropFlowError) Unwrap() error
type MissingPrimaryKeyError ¶
type MissingPrimaryKeyError struct {
Table string
}
func (*MissingPrimaryKeyError) Error ¶
func (e *MissingPrimaryKeyError) Error() string
type MongoInvalidIdValueError ¶
type MongoInvalidIdValueError struct {
Table string
}
func NewInvalidIdValueError ¶
func NewInvalidIdValueError(table string) *MongoInvalidIdValueError
func (*MongoInvalidIdValueError) Error ¶
func (e *MongoInvalidIdValueError) Error() string
type MySQLGeometryParseError ¶
type MySQLGeometryParseError struct {
// contains filtered or unexported fields
}
MySQLGeometryParseError wraps go-geos WKB parse failures so they can be classified as MySQL-source errors without string-matching at the alerting layer. The underlying message comes from go-geos C code and is not unique to MySQL on its own.
func NewMySQLGeometryParseError ¶
func NewMySQLGeometryParseError(err error) *MySQLGeometryParseError
func (*MySQLGeometryParseError) Error ¶
func (e *MySQLGeometryParseError) Error() string
func (*MySQLGeometryParseError) Unwrap ¶
func (e *MySQLGeometryParseError) Unwrap() error
type MySQLIncompatibleColumnTypeError ¶
type MySQLIncompatibleColumnTypeError struct {
TableName string
ColumnName string
// contains filtered or unexported fields
}
func (*MySQLIncompatibleColumnTypeError) Error ¶
func (e *MySQLIncompatibleColumnTypeError) Error() string
type MySQLStreamingError ¶
type MySQLStreamingError struct {
Retryable bool
// contains filtered or unexported fields
}
func NewMySQLStreamingError ¶
func NewMySQLStreamingError(err error) *MySQLStreamingError
func (*MySQLStreamingError) Error ¶
func (e *MySQLStreamingError) Error() string
func (*MySQLStreamingError) Unwrap ¶
func (e *MySQLStreamingError) Unwrap() error
type MySQLUnsupportedBinlogRowMetadataError ¶
func NewMySQLUnsupportedBinlogRowMetadataError ¶
func NewMySQLUnsupportedBinlogRowMetadataError(schema string, table string) *MySQLUnsupportedBinlogRowMetadataError
func (*MySQLUnsupportedBinlogRowMetadataError) Error ¶
func (e *MySQLUnsupportedBinlogRowMetadataError) Error() string
type MySQLUnsupportedDDLError ¶
type MySQLUnsupportedDDLError struct {
TableName string
}
func NewMySQLUnsupportedDDLError ¶
func NewMySQLUnsupportedDDLError(tableName string) *MySQLUnsupportedDDLError
func (*MySQLUnsupportedDDLError) Error ¶
func (e *MySQLUnsupportedDDLError) Error() string
type NormalizationError ¶
type NormalizationError struct {
// contains filtered or unexported fields
}
func NewNormalizationError ¶
func NewNormalizationError(err error) *NormalizationError
func (*NormalizationError) Error ¶
func (e *NormalizationError) Error() string
func (*NormalizationError) Unwrap ¶
func (e *NormalizationError) Unwrap() error
type NotFoundError ¶
type NotFoundError struct {
// contains filtered or unexported fields
}
func NewNotFoundError ¶
func NewNotFoundError(err error) *NotFoundError
func (*NotFoundError) Error ¶
func (e *NotFoundError) Error() string
func (*NotFoundError) Unwrap ¶
func (e *NotFoundError) Unwrap() error
type NumericOutOfRangeError ¶
type NumericOutOfRangeError struct {
DestinationTable string
DestinationColumn string
// contains filtered or unexported fields
}
func NewNumericOutOfRangeError ¶
func NewNumericOutOfRangeError(err error, destinationTable, destinationColumn string) *NumericOutOfRangeError
func (*NumericOutOfRangeError) Error ¶
func (e *NumericOutOfRangeError) Error() string
func (*NumericOutOfRangeError) Unwrap ¶
func (e *NumericOutOfRangeError) Unwrap() error
type NumericTruncatedError ¶
type NumericTruncatedError struct {
DestinationTable string
DestinationColumn string
// contains filtered or unexported fields
}
func NewNumericTruncatedError ¶
func NewNumericTruncatedError(err error, destinationTable, destinationColumn string) *NumericTruncatedError
func (*NumericTruncatedError) Error ¶
func (e *NumericTruncatedError) Error() string
func (*NumericTruncatedError) Unwrap ¶
func (e *NumericTruncatedError) Unwrap() error
type PeerCreateError ¶
type PeerCreateError struct {
// contains filtered or unexported fields
}
func NewPeerCreateError ¶
func NewPeerCreateError(err error) *PeerCreateError
func (*PeerCreateError) Error ¶
func (e *PeerCreateError) Error() string
func (*PeerCreateError) Unwrap ¶
func (e *PeerCreateError) Unwrap() error
type PostgresLogicalMessageProcessingError ¶
type PostgresLogicalMessageProcessingError struct {
// contains filtered or unexported fields
}
func NewPostgresLogicalMessageProcessingError ¶
func NewPostgresLogicalMessageProcessingError(err error) *PostgresLogicalMessageProcessingError
func (*PostgresLogicalMessageProcessingError) Error ¶
func (e *PostgresLogicalMessageProcessingError) Error() string
func (*PostgresLogicalMessageProcessingError) Unwrap ¶
func (e *PostgresLogicalMessageProcessingError) Unwrap() error
type PostgresSetupError ¶
type PostgresSetupError struct {
// contains filtered or unexported fields
}
PostgresSetupError represents errors during setup of Postgres peers, maybe we can later replace with a more generic error type
func NewPostgresSetupError ¶
func NewPostgresSetupError(err error) *PostgresSetupError
func (*PostgresSetupError) Error ¶
func (e *PostgresSetupError) Error() string
func (*PostgresSetupError) Unwrap ¶
func (e *PostgresSetupError) Unwrap() error
type PostgresWalError ¶
type PostgresWalError struct {
Msg *pgproto3.ErrorResponse
// contains filtered or unexported fields
}
func NewPostgresWalError ¶
func NewPostgresWalError(err error, msg *pgproto3.ErrorResponse) *PostgresWalError
func (*PostgresWalError) Error ¶
func (e *PostgresWalError) Error() string
func (*PostgresWalError) UnderlyingError ¶
func (e *PostgresWalError) UnderlyingError() *pgproto3.ErrorResponse
func (*PostgresWalError) Unwrap ¶
func (e *PostgresWalError) Unwrap() error
type PrimaryKeyModifiedError ¶
type PrimaryKeyModifiedError struct {
TableName string
ColumnName string
// contains filtered or unexported fields
}
func NewPrimaryKeyModifiedError ¶
func NewPrimaryKeyModifiedError(err error, tableName, columnName string) *PrimaryKeyModifiedError
func (*PrimaryKeyModifiedError) Error ¶
func (e *PrimaryKeyModifiedError) Error() string
func (*PrimaryKeyModifiedError) Unwrap ¶
func (e *PrimaryKeyModifiedError) Unwrap() error
type PublicationMissingError ¶
type PublicationMissingError struct {
PublicationName string
}
func NewPublicationMissingError ¶
func NewPublicationMissingError(publicationName string) *PublicationMissingError
func (*PublicationMissingError) Error ¶
func (e *PublicationMissingError) Error() string
type RDSIAMAuthError ¶
type RDSIAMAuthError struct {
// contains filtered or unexported fields
}
func NewRDSIAMAuthError ¶
func NewRDSIAMAuthError(err error) *RDSIAMAuthError
func (*RDSIAMAuthError) Error ¶
func (e *RDSIAMAuthError) Error() string
func (*RDSIAMAuthError) Unwrap ¶
func (e *RDSIAMAuthError) Unwrap() error
type RecordMetricsError ¶
type RecordMetricsError struct {
// contains filtered or unexported fields
}
func NewRecordMetricsError ¶
func NewRecordMetricsError(err error) *RecordMetricsError
func (*RecordMetricsError) Error ¶
func (e *RecordMetricsError) Error() string
func (*RecordMetricsError) Unwrap ¶
func (e *RecordMetricsError) Unwrap() error
type ReplStateDesyncError ¶
type ReplStateDesyncError struct {
Message string
}
func NewReplStateDesyncError ¶
func NewReplStateDesyncError(message string) *ReplStateDesyncError
func (*ReplStateDesyncError) Error ¶
func (e *ReplStateDesyncError) Error() string
type ReplicaIdentityIndexError ¶
type ReplicaIdentityIndexError struct {
Table string
}
func (*ReplicaIdentityIndexError) Error ¶
func (e *ReplicaIdentityIndexError) Error() string
type ReplicaIdentityNothingError ¶
type ReplicaIdentityNothingError struct {
Table string
}
func (*ReplicaIdentityNothingError) Error ¶
func (e *ReplicaIdentityNothingError) Error() string
type SSHTunnelSetupError ¶
type SSHTunnelSetupError struct {
// contains filtered or unexported fields
}
SSHTunnelSetupError represents errors during SSH Tunnel Setup, the SSH library we use does not provide a common error type, just does fmt.Errorf
func NewSSHTunnelSetupError ¶
func NewSSHTunnelSetupError(err error) *SSHTunnelSetupError
func (*SSHTunnelSetupError) Error ¶
func (e *SSHTunnelSetupError) Error() string
func (*SSHTunnelSetupError) Unwrap ¶
func (e *SSHTunnelSetupError) Unwrap() error
type SlotMissingError ¶
type SlotMissingError struct {
SlotName string
}
func NewSlotMissingError ¶
func NewSlotMissingError(slotName string) *SlotMissingError
func (*SlotMissingError) Error ¶
func (e *SlotMissingError) Error() string
type TableRemovalInCancellationError ¶
type TableRemovalInCancellationError struct {
// contains filtered or unexported fields
}
func NewRemovedTablesInCancellationError ¶
func NewRemovedTablesInCancellationError(err error) *TableRemovalInCancellationError
func (*TableRemovalInCancellationError) Error ¶
func (e *TableRemovalInCancellationError) Error() string
func (*TableRemovalInCancellationError) Unwrap ¶
func (e *TableRemovalInCancellationError) Unwrap() error
type TablesNotInPublicationError ¶
type TablesNotInPublicationError struct {
// contains filtered or unexported fields
}
func NewTablesNotInPublicationError ¶
func NewTablesNotInPublicationError(tables []string, publicationName string) *TablesNotInPublicationError
func (*TablesNotInPublicationError) Error ¶
func (e *TablesNotInPublicationError) Error() string
Click to show internal directories.
Click to hide internal directories.